@@ -12,8 +12,8 @@
 G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (3)
-#define SOUP_MINOR_VERSION (2)
-#define SOUP_MICRO_VERSION (2)
+#define SOUP_MINOR_VERSION (4)
+#define SOUP_MICRO_VERSION (3)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -63,6 +63,15 @@ G_BEGIN_DECLS
  * Since: 3.2
  */
 #define SOUP_VERSION_3_2 (G_ENCODE_VERSION (3, 2))
+/**
+ * SOUP_VERSION_3_4:
+ *
+ * A macro that evaluates to the 3.4 version of libsoup, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.4
+ */
+#define SOUP_VERSION_3_4 (G_ENCODE_VERSION (3, 4))
 
 
 /* evaluates to the current stable version; for development cycles,
@@ -211,6 +220,33 @@ G_BEGIN_DECLS
 #else
 # define SOUP_AVAILABLE_IN_3_2                 _SOUP_EXTERN
 #endif
+/**
+ * SOUP_DEPRECATED_IN_3_4:
+ * A macro used to indicate a symbol was deprecated in this version.
+ */
+/**
+ * SOUP_DEPRECATED_IN_3_4_FOR:
+ * @f: The recommended replacement function.
+ *
+ * A macro used to indicate a symbol was deprecated in this version with a replacement.
+ */
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_3_4
+# define SOUP_DEPRECATED_IN_3_4                SOUP_DEPRECATED
+# define SOUP_DEPRECATED_IN_3_4_FOR(f)         SOUP_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_3_4                _SOUP_EXTERN
+# define SOUP_DEPRECATED_IN_3_4_FOR(f)         _SOUP_EXTERN
+#endif
+
+/**
+ * SOUP_AVAILABLE_IN_3_4:
+ * A macro used to indicate a symbol is available in this version or later.
+ */
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_3_4
+# define SOUP_AVAILABLE_IN_3_4                 SOUP_UNAVAILABLE(3, 4)
+#else
+# define SOUP_AVAILABLE_IN_3_4                 _SOUP_EXTERN
+#endif
 
 
 SOUP_AVAILABLE_IN_ALL
